@@ -253,7 +253,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
         if asfarray(f).size != 1: self.err('unexpected f size. The function should be redefined in OO child class, inform OO developers')
         return f
 
-    def inspire(self, newProb, sameConstraints=True):
+    def fill(self, newProb, sameConstraints=True):
         # fills some fields of new prob with old prob values
         newProb.castFrom = self.probType
 
@@ -436,7 +436,7 @@ class baseProblem(oomatrix, residuals, ooTextOutput):
                 if type(val) in (str, string_):
                     self._categoricalVars.add(key)
                     key.formAuxDomain()
-                    self.x0[key] = searchsorted(key.aux_domain, val, 'left')
+                    self.x0[key] = key.aux_domain[val]#searchsorted(key.aux_domain, val, 'left')
                 elif key.domain is not None and key.domain is not bool and key.domain is not 'bool' \
                 and key.domain is not int and key.domain is not 'int' and val not in key.domain:
                     self.x0[key] = key.domain[0]
